Welcome to PowNet's documentation!
===================================

**Pownet** is a least-cost optimization model for simulating the Unit Commitment and Economic Dispatch (UC/ED) of large-scale (regional to country) power systems.


Content
===================================

.. toctree::

   pages/background
   pages/installation
   pages/architecture
   pages/quickstarter
   pages/technical
   pages/support
   pages/release
   pages/glossary
   pages/license
   pages/acknowledgement
   pages/publications
   api_pages/api
